<?php
  /**
   * Includes the config file, and global functions to be
   * included in every page.
   * @author Jason Grafinger
   */

  //Add system-wide settings and configurations.
  // Only added for the calling page, so variables
  // set in config.php must be passed to all functions.
  require("config.php");

  //Now check to see that config.php worked!
  if(!is_array($master))
  {
    die("The application is not initialized correctly, please re-run the configuration utility.");
  }

  function connect($master) {
    /**
     * Connects to MySQL and selects the db.
     * @param $master The master config array.
     * @return $connect Connection object if connected, NULL otherwise.
     */

    $connect = mysql_connect($master['dbHost'],$master['dbUsername'],
      $master['dbPassword']) OR die("Could not connect:"
      . mysql_error());
    mysql_select_db($master['dbName'],$connect)
      OR die("Could not select database: " . mysql_error());

    return $connect;
  }

  function checkAuth() {
    /**
     * Checks session variables for authentication, redirects
     * if user is not authenticated.
     * 
     */

    if(!isset($_SESSION['userType']))
    {
      //User is not authenticated, redirect
      header("Location: " . $master['systemRoot']);
    }
  }

  function writeTop($pgTitle,$includeSystemName,$master,$errorType) {
    /**
     * Writes the top HTML for a calling page.
     * @param $pgTitle The title for the calling page.
     * @param $includeSystemName Boolean for whether to
     *        include the name of the system in the title.
     * @param $master The master config array.
     * @param $errorType A string possibly containing an error code
     */

    if(!isset($pgTitle)) {
      $pgTitle = "";
      $includeSystemName = true;
    }

    if(isset($includeSystemName) && $includeSystemName == true) {
      $pgTitle = $pgTitle . $master['systemName'];
    }

    //Write the top of the template
    $topHTML = "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.1//EN\"
    \"http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd\">
<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"en\" >
  <head>
    <title>" . $pgTitle . "</title>\n";

    if(isset($master['extraJavascript']))
    {
      $topHTML .= $master['extraJavascript'];
    }

    $topHTML .= "    <style type=\"text/css\">
      body {
        width:600px;
        background:#EEEEEE;
        font-size: 1em;
        font-family:";

    $topHTML .= (isset($master['fontStyles']['body'])) ?
      $master['fontStyles']['body'] . ";" : "times,serif;";

    $topHTML .= "
      }

      input,textarea {
        background: #DADADA;
      }

      h1 {
        font-weight:lighter;
        font-family:";

    //Adds custom font settings if available
    $topHTML .= (isset($master['fontStyles']['h1'])) ?
      $master['fontStyles']['h1'] . ";" : "arial,sans-serif;";

    $topHTML .= "
        font-size:200%;
      }

      h2 {
        font-weight:lighter;
        font-family:";

    //Adds custom font settings if available
    $topHTML .= (isset($master['fontStyles']['h2'])) ?
      $master['fontStyles']['h2'] . ";" : "arial,sans-serif;";

    $topHTML .= "
        font-size:150%;
      }

      .msgBox {
        width:450px;
        border:2px solid;
      }

      .msgHeader {
        width:100%;
        font-weight:bold;
        color:#DDDDDD;
      }

      .msgBody {
        width:100%;
        padding:5px;
      }

      .errorMsgBox {
        background:#FFECEC;
        border-color:#880000;
      }

      .errorMsgHeader {
        background:#880000;
        color:#FFECEC;
      }
    </style>
  </head>
  <body>
    <div>
      <h1>" . $pgTitle . "</h1><hr />\n";

    //If an error is set by the calling page, display it
    if(isset($errorType)) {
      //Pre-set error?
      if(isset($master['error'][$errorType]['header']) &&
	 isset($master['error'][$errorType]['body'])) {
	$errorHeader = $master['error'][$errorType]['header'];
	$errorBody = $master['error'][$errorType]['body'];
      }
      //Unknown error
      else {
	$errorHeader = "Unspecified Error";
	$errorBody = "An error occurred, but it is unknown to the system";
      }
      $topHTML .= "
      <div class=\"msgBox errorMsgBox\">
        <div class=\"msgHeader errorMsgHeader\">
          " . $errorHeader . "
        </div>
        <div class=\"msgBody errorMsgBody\">
          " . $errorBody . "
        </div>
      </div>
      <hr />\n";
    }

    echo $topHTML;
  }

  function writeBottom() {
    /**
     * Writes the bottom HTML for the calling page.
     */

    echo "    </div>
  </body>
</html>";
  }

  function writeNav($userType)
  {
    /**
     * Writes appropriate navigation for a given user.
     * @param $userType Type of user.
     */

    $navHTML = "";

    if(!isset($userType))
    {
      die("Invalid user type");
    }
    else
    {
      $navHTML = "      <div id=\"nav\">\n";
      if($_SESSION['userType'] == "std")
      {
        $navHTML .= "        <a href=\"addrequest.php\">Add A Request</a> |\n";
      }
      $navHTML .= "        <a href=\"viewrequests.php\">View Requests</a> | 
        <a href=\"logout.php\">Logout</a>
      </div>\n";
    }

    echo $navHTML;
  }

  function getTimestampForXWeekdays($x,$startDate)
  {
    /**
     * Returns a timestamp for $x WEEKDAYS (not weekends) in the future
     */

    $newX = $x;
    for($i = 1;$i <= $newX;$i++)
    {
      $dayOfWeek = date("D",strtotime(sprintf("+%s Day",$i),$startDate));
      if($dayOfWeek == "Sun" || $dayOfWeek == "Sat")
      {
        $newX++;
      }
    }

    return strtotime(sprintf("+%s Day",$newX),$startDate);
  }

  function isValidTimespanFormat($time)
  {
    /**
     * Returns whether $time matches a specified format.
     */

    //Validate time through regular expressions
    $oneTime = "(0?\d|1[0-2]):[0-5][0-9][AP]M";
    $oneSpan = sprintf("%s\s*-\s*%s",$oneTime,$oneTime);
    $spanRegEx = sprintf("/^%s(\s*;\s*%s)*$/i",$oneSpan,$oneSpan);

    return preg_match($spanRegEx,$time);
  }

?>
